function [call, put, conf] = MC(K, S1, S2, sigma1, sigma2, mu1, mu2, rho, r, T, N)
    % K = strike price
    % S1 = spot price for asset 1
    % S2 = spot price for asset 2
    % sigma1 = volatility for asset 1
    % sigma2 = volatility for asset 2
    % mu1 = cost of carry for asset 1
    % mu2 = cost of carry for asset 2
    % rho = correlation between assets
    % r = risk-free rate
    % T = time to maturity
    % N = number of simulations
    
    % We generate two standard Gaussian vectors
    U = randn(N,1) ;
    V = randn(N,1) ;
    
    % We generate final correlated asset prices from the 2 random vectors
    S1_fin = S1 * exp( (mu1-0.5*sigma1^2)*T + sigma1*rho*sqrt(T)*U + sigma2*sqrt(1-rho^2)*sqrt(T)*V ) ;
    S2_fin = S2 * exp( (mu2-0.5*sigma2^2)*T + sigma2*sqrt(T)*U ) ;
    
    % We compute the payoff vector for both call and put
    resC = max((S1_fin - S2_fin) - K, 0) ;
    resP = max(K - (S1_fin - S2_fin), 0) ;
    
    % We finally discount the average of the payoff
    call = exp(-r*T) * mean(resC) ;
    put = exp(-r*T) * mean(resP) ;
    
    % We compute the variance and the confidence intervall
    var = sum((resC-mean(resC)).^2)/(N-1) ;
    conf = 1.96*var/sqrt(N) ;
end