function [call, put, conf] = antitheticMC(K, S1, S2, sigma1, sigma2, mu1, mu2, rho, r, T, N)
    % K = strike price
    % S1 = spot price for asset 1
    % S2 = spot price for asset 2
    % sigma1 = volatility for asset 1
    % sigma2 = volatility for asset 2
    % mu1 = cost of carry for asset 1
    % mu2 = cost of carry for asset 2
    % rho = correlation between assets
    % r = risk-free rate
    % T = time to maturity
    % N = number of simulations
    
    % We generate two standard Gaussian vectors
    U = randn(N,1) ;
    V = randn(N,1) ;
    % We generate the antithetic random vectors
    nU = -U ;
    nV = -V ;
    
    % We generate final prices for both assets from both random vectors
    pS1_fin = S1 * exp( (mu1-0.5*sigma1^2)*T + sigma1*rho*sqrt(T)*U + sigma2*sqrt(1-rho^2)*sqrt(T)*V ) ;
    nS1_fin = S1 * exp( (mu1-0.5*sigma1^2)*T + sigma1*rho*sqrt(T)*nU + sigma2*sqrt(1-rho^2)*sqrt(T)*nV ) ;
    pS2_fin = S2 * exp( (mu2-0.5*sigma2^2)*T + sigma2*sqrt(T)*U ) ;
    nS2_fin = S2 * exp( (mu2-0.5*sigma2^2)*T + sigma2*sqrt(T)*nU ) ;
    
    % We compute the payoff vector for the call for both random vectors
    resCp = max((pS1_fin - pS2_fin) - K, 0) ;
    resCn = max((nS1_fin - nS2_fin) - K, 0) ;
    % We compute the payoff vector for the put for both random vectors
    resPp = max(K - (pS1_fin - pS2_fin), 0) ;
    resPn = max(K - (nS1_fin - nS2_fin), 0) ;
    
    % We compute the average between normal and antithetic payoffs
    resC = 0.5 * (resCp + resCn) ;
    resP = 0.5 * (resPp + resPn) ;
    
    % We finally discount the average of the payoff
    call = exp(-r*T) * mean(resC) ;
    put = exp(-r*T) * mean(resP) ;
    
    % We compute the variance and the confidence intervall
    var = sum((resC-mean(resC)).^2)/(N-1) ;
    conf = 1.96*var/sqrt(N) ;
end